@@ -1,16 +1,14 @@
-"""Functional interface to hypergraph methods and assorted utilities.
-"""
+"""Functional interface to hypergraph methods and assorted utilities."""
 
 from collections import Counter
 
-import xgi
-from xgi.exception import XGIError
+from ..exception import XGIError
 
 __all__ = [
     "max_edge_order",
     "is_possible_order",
     "is_uniform",
-    "egonet",
+    "edge_neighborhood",
     "degree_counts",
     "degree_histogram",
     "unique_edge_sizes",
@@ -31,7 +29,7 @@ def max_edge_order(H):
 
     Parameters
     ----------
-    H : xgi.Hypergraph
+    H : Hypergraph
         The hypergraph of interest.
 
     Returns
@@ -52,7 +50,7 @@ def is_possible_order(H, d):
 
     Parameters
     ----------
-    H : xgi.Hypergraph
+    H : Hypergraph
         The hypergraph of interest.
     d : int
         Order for which to check.
@@ -63,7 +61,7 @@ def is_possible_order(H, d):
         Whether `d` is a possible order.
 
     """
-    d_max = xgi.max_edge_order(H)
+    d_max = max_edge_order(H)
     return (d >= 1) and (d <= d_max)
 
 
@@ -85,6 +83,7 @@ def is_uniform(H):
     --------
     This function can be used as a boolean check:
 
+    >>> import xgi
     >>> H = xgi.Hypergraph([(0, 1, 2), (1, 2, 3), (2, 3, 4)])
     >>> xgi.is_uniform(H)
     2
@@ -102,27 +101,27 @@ def is_uniform(H):
     return edge_sizes.pop() - 1  # order of all edges
 
 
-def egonet(H, n, include_self=False):
-    """The egonet of the specified node.
+def edge_neighborhood(H, n, include_self=False):
+    """The edge neighborhood of the specified node.
 
-    The egonet of a node `n` in a hypergraph `H` is another hypergraph whose nodes
-    are the neighbors of `n` and its edges are all the edges in `H` that contain
-    `n`.  Usually, the egonet do not include `n` itself.  This can be controlled
+    The edge neighborhood of a node `n` in a hypergraph `H` is an edgelist of all the edges
+    containing `n` and its edges are all the edges in `H` that contain
+    `n`.  Usually, the edge neighborhood does not include `n` itself.  This can be controlled
     with `include_self`.
 
     Parameters
     ----------
-    H : xgi.Hypergraph
+    H : Hypergraph
         THe hypergraph of interest
     n : node
-        Node whose egonet is needed.
+        Node whose edge_neighborhood is needed.
     include_self : bool (default False)
-        Whether the egonet contains `n`.
+        Whether the edge_neighborhood contains `n`.
 
     Returns
     -------
     list
-        An edgelist of the egonet of `n`.
+        An edgelist of the edge_neighborhood of `n`.
 
     See Also
     --------
@@ -132,11 +131,11 @@ def egonet(H, n, include_self=False):
     --------
     >>> import xgi
     >>> H = xgi.Hypergraph([[1, 2, 3], [3, 4], [4, 5, 6]])
-    >>> H.neighbors(3)
+    >>> H.nodes.neighbors(3)
     {1, 2, 4}
-    >>> xgi.egonet(H, 3)
+    >>> xgi.edge_neighborhood(H, 3)
     [[1, 2], [4]]
-    >>> xgi.egonet(H, 3, include_self=True)
+    >>> xgi.edge_neighborhood(H, 3, include_self=True)
     [[1, 2, 3], [3, 4]]
 
     """
@@ -174,8 +173,9 @@ def degree_counts(H):
     >>> H = xgi.Hypergraph(hyperedge_list)
     >>> xgi.degree_counts(H)
     [0, 3, 1]
+
     """
-    counts = Counter(d for n, d in H.degree())
+    counts = Counter(H.degree().values())
     return [counts.get(i, 0) for i in range(max(counts) + 1)]
 
 
@@ -204,8 +204,9 @@ def degree_histogram(H):
     >>> H = xgi.Hypergraph(hyperedge_list)
     >>> xgi.degree_histogram(H)
     ([1, 2], [3, 1])
+
     """
-    counts = Counter(d for n, d in H.degree())
+    counts = Counter(H.degree().values())
     degrees = []
     heights = []
     for d, c in sorted(counts.items(), key=lambda kv: kv[0]):
@@ -235,7 +236,7 @@ def frozen(*args, **kwargs):
 
     Raises
     ------
-    xgi.XGIError
+    XGIError
         Raises error when user tries to modify the hypergraph
 
     Examples
@@ -248,6 +249,7 @@ def frozen(*args, **kwargs):
     >>> H.add_node(5)
     Traceback (most recent call last):
     xgi.exception.XGIError: Frozen hypergraph can't be modified
+
     """
     raise XGIError("Frozen hypergraph can't be modified")
 
@@ -281,6 +283,7 @@ def freeze(H):
     >>> H.add_node(5)
     Traceback (most recent call last):
     xgi.exception.XGIError: Frozen hypergraph can't be modified
+
     """
     H.add_node = frozen
     H.add_nodes_from = frozen
@@ -324,6 +327,7 @@ def is_frozen(H):
     <xgi.classes.hypergraph.Hypergraph object at 0x...>
     >>> xgi.is_frozen(H)
     True
+
     """
     try:
         return H.frozen
@@ -362,11 +366,12 @@ def create_empty_copy(H, with_data=True):
     NodeView((1, 2, 3, 4))
     >>> H_copy.edges
     EdgeView(())
+
     """
     H_copy = H.__class__()
     H_copy.add_nodes_from(H.nodes)
     if with_data:
-        xgi.set_node_attributes(H_copy, dict(H._node_attr))
+        set_node_attributes(H_copy, dict(H._node_attr))
         H_copy._hypergraph.update(H._hypergraph)
     return H_copy
 
@@ -413,6 +418,7 @@ def set_node_attributes(H, values, name=None):
 
     Note that if the dictionary contains nodes that are not in `G`, the
     values are silently ignored.
+
     """
     # Set node attributes based on type of `values`
     if name is not None:  # `values` must not be a dict of dict
@@ -464,7 +470,7 @@ def get_node_attributes(H, name=None):
 
 
 def set_edge_attributes(H, values, name=None):
-    """Set the edge attributes from a value or a dictionary of values
+    """Set the edge attributes from a value or a dictionary of values.
 
     Parameters
     ----------
@@ -576,8 +582,7 @@ def is_empty(H):
 
 
 def maximal_simplices(SC):
-    """
-    Return the IDs associated to the maximal simplices of the input SC.
+    """Return the IDs of the maximal simplices of the input.
 
     Parameters
     ----------
@@ -586,18 +591,17 @@ def maximal_simplices(SC):
     Returns
     -------
     maximal_simplices : list(int)
-        A list of IDs correspondent to the maximal simplices in the provided simplicial complex.
+        A list of IDs correspondent to the maximal simplices in `SC`.
 
-    Notes
-    --------
-    The output is not a xgi's SimplicialComplex since, by construction,
-    that would automatically add back the non-maximal simplices just removed.
     """
+    # This import needs to happen when this function is called, not when it is
+    # defined.  Otherwise, a circular import error would happen.
+    from .simplicialcomplex import SimplicialComplex
 
-    if type(SC) != xgi.classes.simplicialcomplex.SimplicialComplex:
-        raise XGIError("The input must be a xgi.SimplicialComplex")
+    if not isinstance(SC, SimplicialComplex):
+        raise XGIError("The input must be a SimplicialComplex")
 
-    maximal_simplices = []
+    max_simplices = []
 
     for i in SC.edges:
         maximal = True
@@ -607,5 +611,5 @@ def maximal_simplices(SC):
                 maximal = False
                 break
         if maximal:
-            maximal_simplices.append(i)
-    return maximal_simplices
+            max_simplices.append(i)
+    return max_simplices
