@@ -1,23 +1,29 @@
 """Base class for undirected hypergraphs."""
 from collections.abc import Hashable, Iterable
 from copy import deepcopy
+from itertools import count
 from warnings import warn
 
 import numpy as np
 
-import xgi
-import xgi.convert as convert
-from xgi.classes.reportviews import DegreeView, EdgeSizeView, EdgeView, NodeView
-from xgi.exception import IDNotFound, XGIError
-from xgi.utils import XGICounter
+from ..exception import IDNotFound, XGIError
+from .hypergraphviews import subhypergraph
+from .reportviews import EdgeView, NodeView
 
 __all__ = ["Hypergraph"]
 
 
 class IDDict(dict):
+    """A dict that holds (node or edge) IDs.
+
+    For internal use only.  Adds input validation functionality to the internal dicts
+    that hold nodes and edges in a network.
+
+    """
+
     def __getitem__(self, item):
         try:
-            return super().__getitem__(item)
+            return dict.__getitem__(self, item)
         except KeyError as e:
             raise IDNotFound(f"ID {item} not found") from e
 
@@ -25,13 +31,13 @@ class IDDict(dict):
         if item is None:
             raise XGIError("None cannot be a node or edge")
         try:
-            return super().__setitem__(item, value)
+            return dict.__setitem__(self, item, value)
         except KeyError as e:
             raise IDNotFound(f"ID {item} not found") from e
 
     def __delitem__(self, item):
         try:
-            return super().__delitem__(item)
+            return dict.__delitem__(self, item)
         except KeyError as e:
             raise IDNotFound(f"ID {item} not found") from e
 
@@ -71,9 +77,14 @@ class Hypergraph:
     Unique IDs are assigned to each node and edge internally and are used to refer to
     them throughout.
 
-    The attr keyword arguments are added as hypergraph attributes. To add node or ede
+    The `attr` keyword arguments are added as hypergraph attributes. To add node or ede
     attributes see :meth:`add_node` and :meth:`add_edge`.
 
+    In addition to the methods listed in this page, other methods defined in the `stats`
+    package are also accessible via the `Hypergraph` class.  For more details, see the
+    `tutorial
+    <https://github.com/ComplexGroupInteractions/xgi/blob/main/tutorials/Tutorial%206%20-%20Statistics.ipynb>`_.
+
     Examples
     --------
     >>> import xgi
@@ -91,7 +102,7 @@ class Hypergraph:
     _hypergraph_attr_dict_factory = dict
 
     def __init__(self, incoming_data=None, **attr):
-        self._edge_uid = XGICounter()
+        self._edge_uid = count()
         self._hypergraph = self._hypergraph_attr_dict_factory()
         self._node = self._node_dict_factory()
         self._node_attr = self._node_attr_dict_factory()
@@ -105,7 +116,11 @@ class Hypergraph:
         """An :class:`~xgi.classes.reportviews.EdgeView` of the hypergraph."""
 
         if incoming_data is not None:
-            convert.convert_to_hypergraph(incoming_data, create_using=self)
+            # This import needs to happen when this function is called, not when it is
+            # defined.  Otherwise, a circular import error would happen.
+            from ..convert import convert_to_hypergraph
+
+            convert_to_hypergraph(incoming_data, create_using=self)
         self._hypergraph.update(attr)  # must be after convert
 
     def __str__(self):
@@ -177,12 +192,29 @@ class Hypergraph:
         """Write hypergraph attribute."""
         self._hypergraph[attr] = val
 
+    def __getattr__(self, attr):
+        stat = getattr(self.nodes, attr, None)
+        if stat is None:
+            stat = getattr(self.edges, attr, None)
+        if stat is None:
+            raise AttributeError(
+                f'stat "{attr}" not among available node or edge stats'
+            )
+
+        def func(node=None, *args, **kwargs):
+            val = stat(*args, **kwargs).asdict()
+            return val if node is None else val[node]
+
+        return func
+
     @property
     def nodes(self):
+        """A :class:`NodeView` of this network."""
         return self._nodeview
 
     @property
     def edges(self):
+        """An :class:`EdgeView` of this network."""
         return self._edgeview
 
     @property
@@ -233,33 +265,6 @@ class Hypergraph:
         """
         return len(self._edge)
 
-    def neighbors(self, n):
-        """Find the neighbors of a node.
-        The neighbors of a node are those nodes that appear in at least one edge with
-        said node.
-        Parameters
-        ----------
-        n : node
-            Node to find neighbors of.
-        Returns
-        -------
-        set
-            A set of the neighboring nodes
-        See Also
-        --------
-        egonet
-        Examples
-        --------
-        >>> import xgi
-        >>> hyperedge_list = [[1, 2], [2, 3, 4]]
-        >>> H = xgi.Hypergraph(hyperedge_list)
-        >>> H.neighbors(1)
-        {2}
-        >>> H.neighbors(2)
-        {1, 3, 4}
-        """
-        return {i for e in self._node[n] for i in self._edge[e]}.difference({n})
-
     def add_node(self, node, **attr):
         """Add one node with optional attributes.
 
@@ -414,8 +419,9 @@ class Hypergraph:
         Examples
         --------
 
-        Add edges with ir without specifying an edge id.
+        Add edges with or without specifying an edge id.
 
+        >>> import xgi
         >>> H = xgi.Hypergraph()
         >>> H.add_edge([1, 2, 3])
         >>> H.add_edge([3, 4], id='myedge')
@@ -437,7 +443,7 @@ class Hypergraph:
         if not members:
             raise XGIError("Cannot add an empty edge")
 
-        uid = self._edge_uid() if not id else id
+        uid = next(self._edge_uid) if not id else id
         self._edge[uid] = []
         for node in members:
             if node not in self._node:
@@ -457,7 +463,7 @@ class Hypergraph:
         ebunch_to_add : Iterable
 
             An iterable of edges.  This may be a dict of the form `{edge_id:
-            edge_members}`, or it may be an iterable of iterables, wher each element
+            edge_members}`, or it may be an iterable of iterables, where each element
             contains the members of the edge specified as valid node IDs.
             Alternatively, each element could also be a tuple in any of the following
             formats:
@@ -473,7 +479,7 @@ class Hypergraph:
             i.e. you cannot mix different formats.  The iterables containing edge
             members cannot be strings.
 
-        attr : **kwargs, optional
+        attr : \*\*kwargs, optional
             Additional attributes to be assigned to all edges. Attribues specified via
             `ebunch_to_add` take precedence over `attr`.
 
@@ -492,7 +498,7 @@ class Hypergraph:
         >>> import xgi
         >>> H = xgi.Hypergraph()
 
-        When Specify edges by their members only, numeric edge IDs will be assigned
+        When specifying edges by their members only, numeric edge IDs will be assigned
         automatically.
 
         >>> H.add_edges_from([[0, 1], [1, 2], [2, 3, 4]])
@@ -595,11 +601,11 @@ class Hypergraph:
         e = first_edge
         while True:
             if format1:
-                members, uid, eattr = e, self._edge_uid(), {}
+                members, uid, eattr = e, next(self._edge_uid), {}
             elif format2:
                 members, uid, eattr = e[0], e[1], {}
             elif format3:
-                members, uid, eattr = e[0], self._edge_uid(), e[1]
+                members, uid, eattr = e[0], next(self._edge_uid), e[1]
             elif format4:
                 members, uid, eattr = e[0], e[1], e[2]
 
@@ -646,15 +652,15 @@ class Hypergraph:
         -----
         Adding the same edge twice creates a multiedge.
 
-        Example
-        -------
+        Examples
+        --------
+        >>> import xgi
         >>> H = xgi.Hypergraph()
         >>> edges = [(0, 1, 0.3), (0, 2, 0.8)]
         >>> H.add_weighted_edges_from(edges)
         >>> H.edges[0]
         {'weight': 0.3}
 
-
         """
         try:
             self.add_edges_from(
@@ -689,12 +695,12 @@ class Hypergraph:
 
         Examples
         --------
-        Swap the memberships of two nodes.
-
+        >>> import xgi
         >>> H = xgi.Hypergraph([[1, 2, 3], [3, 4]])
         >>> H.double_edge_swap(1, 4, 0, 1)
         >>> H.edges.members()
         [[4, 2, 3], [3, 1]]
+
         """
         # Assign edges to modify
         try:
@@ -746,6 +752,7 @@ class Hypergraph:
 
         Examples
         --------
+        >>> import xgi
         >>> H = xgi.Hypergraph()
         >>> H.add_edge(['apple', 'banana'], 'fruits')
         >>> H.add_node_to_edge('fruits', 'pear')
@@ -868,89 +875,6 @@ class Hypergraph:
         if edges:
             self.add_edges_from(edges)
 
-    def degree(self, nbunch=None, weight=None, order=None, dtype="dict"):
-        """A DegreeView for the Hypergraph.
-
-        The degree is the number of edges adjacent to the node.
-        The weighted node degree is the sum of the edge weights for
-        edges incident to that node.
-
-        This object provides an iterator for (node, degree) as well as
-        lookup for the degree for a single node.
-
-        Parameters
-        ----------
-        nbunch : single node, iterable, or None, default: None
-            The view will only report edges incident to these nodes. If None
-            is specified, the degree of all nodes is computed.
-        weight : string or None, default: None
-           The name of an edge attribute that holds the numerical value used
-           as a weight.  If None, then each edge has weight 1.
-           The degree is the sum of the edge weights adjacent to the node.
-        order : int or None, default: None
-            The size edges for which to compute the degree. If None is
-            specified, all edges are considered.
-        dtype : str, default: "dict"
-            The datatype to return
-
-
-        Returns
-        -------
-        If a single node is requested
-        float or int
-            Degree of the node
-
-        OR if multiple nodes are requested
-        DegreeView object
-            The degrees of the hypergraph capable of iterating (node, degree) pairs
-
-        """
-        degree = DegreeView(
-            self, nbunch=nbunch, weight=weight, order=order, dtype=dtype
-        )
-
-        # handles the single node case.
-        if nbunch in self:
-            return degree[nbunch]
-        return degree
-
-    def edge_size(self, ebunch=None, weight=None, dtype="dict"):
-        """A EdgeSizeView for the Hypergraph as H.edge_size or H.edge_size().
-
-        The edge degree is the number of nodes in that edge, or the edge size.
-        The weighted edge degree is the sum of the node weights for
-        nodes in that edge.
-
-        This object provides an iterator for (edge, degree) as well as
-        lookup for the degree for a single edge.
-
-        Parameters
-        ----------
-        ebunch : single edge, iterable, or all edges (default= all edges)
-            The view will only report sizes of these edges.
-        weight : string or None, optional (default=None)
-           The name of an node attribute that holds the numerical value used
-           as a weight.  If None, then each node has weight 1.
-           The size is the sum of the node weights adjacent to the edge.
-        dtype : str, default: "dict"
-            The datatype to return
-
-        Returns
-        -------
-        If a single edge is requested
-        int
-            size of the edge.
-
-        OR if multiple edges are requested
-        EdgeSizeView object
-            The sizes of the hypergraph edges capable of iterating (edge, size) pairs
-
-        """
-        edge_sizes = EdgeSizeView(self, ebunch=ebunch, weight=weight, dtype=dtype)
-        if ebunch in self:
-            return edge_sizes[ebunch]
-        return edge_sizes
-
     def clear(self, hypergraph_attr=True):
         """Remove all nodes and edges from the graph.
 
@@ -987,7 +911,7 @@ class Hypergraph:
             A copy of the hypergraph.
 
         """
-        return xgi.hypergraphviews.subhypergraph(self)
+        return subhypergraph(self)
 
     def dual(self):
         """The dual of the hypergraph.
@@ -1020,7 +944,7 @@ class Hypergraph:
             View of the edges with a single member.
 
         """
-        return self.edges(order=0)
+        return self.edges.filterby("order", 0)
 
     def remove_singleton_edges(self):
         """Removes all singletons edges from the hypergraph"""
