@@ -4,3 +4,7 @@ class XGIException(Exception):
 
 class XGIError(XGIException):
     """Exception for a serious error in XGI"""
+
+
+class IDNotFound(KeyError):
+    """Raised when a node or edge is not in the hypergraph."""
