@@ -7,8 +7,9 @@ from itertools import combinations
 import networkx as nx
 import numpy as np
 
-import xgi
-from xgi.utils import py_random_state
+from ..classes import SimplicialComplex
+from ..utils import np_random_state, py_random_state
+from .classic import empty_hypergraph, lattice
 
 __all__ = [
     "chung_lu_hypergraph",
@@ -17,6 +18,7 @@ __all__ = [
     "random_simplicial_complex",
     "random_flag_complex_d2",
     "random_flag_complex",
+    "watts_strogatz_hypergraph",
 ]
 
 
@@ -79,7 +81,7 @@ def chung_lu_hypergraph(k1, k2, seed=None):
 
     S = sum(k1.values())
 
-    H = xgi.empty_hypergraph()
+    H = empty_hypergraph()
     H.add_nodes_from(node_labels)
 
     for u in node_labels:
@@ -139,7 +141,7 @@ def dcsbm_hypergraph(k1, k2, g1, g2, omega, seed=None):
 
     Returns
     -------
-    xgi.Hypergraph
+    Hypergraph
 
     Warns
     -----
@@ -201,7 +203,7 @@ def dcsbm_hypergraph(k1, k2, g1, g2, omega, seed=None):
         group = g2[label]
         community2_nodes[group].append(label)
 
-    H = xgi.empty_hypergraph()
+    H = empty_hypergraph()
     H.add_nodes_from(node_labels)
 
     kappa1 = defaultdict(lambda: 0)
@@ -295,7 +297,7 @@ def random_hypergraph(N, ps, seed=None):
 
     hyperedges += [[i] for i in nodes]  # add singleton edges
 
-    H = xgi.empty_hypergraph()
+    H = empty_hypergraph()
     H.add_nodes_from(nodes)
     H.add_edges_from(hyperedges)
 
@@ -352,7 +354,7 @@ def random_simplicial_complex(N, ps, seed=None):
             if seed.random() <= p:
                 simplices.append(simplex)
 
-    S = xgi.SimplicialComplex()
+    S = SimplicialComplex()
     S.add_nodes_from(nodes)
     S.add_simplices_from(simplices)
 
@@ -374,7 +376,7 @@ def random_flag_complex_d2(N, p, seed=None):
 
     Returns
     -------
-    S : xgi.SimplicialComplex
+    SimplicialComplex
 
     Notes
     -----
@@ -395,7 +397,7 @@ def random_flag_complex_d2(N, p, seed=None):
 
     simplices = edges + triad_cliques
 
-    S = xgi.SimplicialComplex()
+    S = SimplicialComplex()
     S.add_nodes_from(nodes)
     S.add_simplices_from(simplices)
 
@@ -420,7 +422,7 @@ def random_flag_complex(N, p, max_order=2, seed=None):
 
     Returns
     -------
-    S : xgi.SimplicialComplex
+    SimplicialComplex
 
     Notes
     -----
@@ -438,8 +440,24 @@ def random_flag_complex(N, p, max_order=2, seed=None):
     # compute all triangles to fill
     max_cliques = list(nx.find_cliques(G))
 
-    S = xgi.SimplicialComplex()
+    S = SimplicialComplex()
     S.add_nodes_from(nodes)
     S.add_simplices_from(max_cliques, max_order=max_order)
 
     return S
+
+
+@np_random_state("seed")
+def watts_strogatz_hypergraph(n, d, k, l, p, seed=None):
+    H = lattice(n, d, k, l)
+    to_remove = []
+    to_add = []
+    for e in H.edges:
+        if seed.random() < p:
+            to_remove.append(e)
+            node = H.edges.members(e)[0]
+            neighbors = seed.choice(H.nodes, size=d - 1)
+            to_add.append(np.append(neighbors, node))
+    H.remove_edges_from(to_remove)
+    H.add_edges_from(to_add)
+    return H
