@@ -222,7 +222,7 @@ def laplacian(H, order=1, rescale_per_node=False, index=False):
 
     Parameters
     ----------
-    HG : xgi.HyperGraph
+    HG : Hypergraph
         Hypergraph
     order : int
         Order of interactions to consider. If order=1 (default),
@@ -271,7 +271,7 @@ def multiorder_laplacian(H, orders, weights, rescale_per_node=False, index=False
 
     Parameters
     ----------
-    HG : xgi.HyperGraph
+    HG : Hypergraph
         Hypergraph
     orders : list of int
         Orders of interactions to consider.
